AbilityUpdate class final

A rule change, as reported to an Ability.on listener.

Constructors

AbilityUpdate(Ability ability, List<RawRule> rules)
Creates the event.
const

Properties

ability Ability
The ability being changed.
final
hashCode int
The hash code for this object.
no setterinherited
rules List<RawRule>
The rules it is changing to.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited